@@ -3,10 +3,7 @@ _live = function() {
 	url = '{{ url_for("running_clients") }}';
 	html = ''
 	$.getJSON(url, function(data) {
-		if (!data.results) {
-			return;
-		}
-		if (data.results.length === 0) {
+		if (!data.results || data.results.length === 0) {
 			document.location = '{{ url_for("home") }}';
 		}
 		$.each(data.results, function(i, c) {
